@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 
 """
-Copyright (c) 2006-2020 sqlmap developers (http://sqlmap.org/)
+Copyright (c) 2006-2022 sqlmap developers (https://sqlmap.org/)
 See the file 'LICENSE' for copying permission
 """
 
@@ -11,34 +11,28 @@ from plugins.generic.enumeration import Enumeration as GenericEnumeration
 class Enumeration(GenericEnumeration):
     def getDbs(self):
         warnMsg = "on Firebird it is not possible to enumerate databases (use only '--tables')"
-        logger.warn(warnMsg)
+        logger.warning(warnMsg)
 
         return []
 
     def getPasswordHashes(self):
         warnMsg = "on Firebird it is not possible to enumerate the user password hashes"
-        logger.warn(warnMsg)
+        logger.warning(warnMsg)
 
         return {}
 
     def searchDb(self):
         warnMsg = "on Firebird it is not possible to search databases"
-        logger.warn(warnMsg)
-
-        return []
-
-    def searchColumn(self):
-        warnMsg = "on Firebird it is not possible to search columns"
-        logger.warn(warnMsg)
+        logger.warning(warnMsg)
 
         return []
 
     def getHostname(self):
         warnMsg = "on Firebird it is not possible to enumerate the hostname"
-        logger.warn(warnMsg)
+        logger.warning(warnMsg)
 
     def getStatements(self):
         warnMsg = "on Firebird it is not possible to enumerate the SQL statements"
-        logger.warn(warnMsg)
+        logger.warning(warnMsg)
 
         return []
