@@ -126,7 +126,7 @@ class Fingerprint(GenericFingerprint):
 
             if not result:
                 warnMsg = "the back-end DBMS is not %s" % DBMS.FIREBIRD
-                logger.warn(warnMsg)
+                logger.warning(warnMsg)
 
                 return False
 
@@ -146,7 +146,7 @@ class Fingerprint(GenericFingerprint):
             return True
         else:
             warnMsg = "the back-end DBMS is not %s" % DBMS.FIREBIRD
-            logger.warn(warnMsg)
+            logger.warning(warnMsg)
 
             return False
 
