@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 
 """
-Copyright (c) 2006-2020 sqlmap developers (http://sqlmap.org/)
+Copyright (c) 2006-2022 sqlmap developers (https://sqlmap.org/)
 See the file 'LICENSE' for copying permission
 """
 
@@ -97,7 +97,7 @@ class Fingerprint(GenericFingerprint):
 
             if not result:
                 warnMsg = "the back-end DBMS is not %s" % DBMS.H2
-                logger.warn(warnMsg)
+                logger.warning(warnMsg)
 
                 return False
             else:
@@ -108,10 +108,10 @@ class Fingerprint(GenericFingerprint):
                 return True
         else:
             warnMsg = "the back-end DBMS is not %s" % DBMS.H2
-            logger.warn(warnMsg)
+            logger.warning(warnMsg)
 
             return False
 
     def getHostname(self):
         warnMsg = "on H2 it is not possible to enumerate the hostname"
-        logger.warn(warnMsg)
+        logger.warning(warnMsg)
