@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 
 """
-Copyright (c) 2006-2020 sqlmap developers (http://sqlmap.org/)
+Copyright (c) 2006-2022 sqlmap developers (https://sqlmap.org/)
 See the file 'LICENSE' for copying permission
 """
 
@@ -81,7 +81,7 @@ class Users(object):
 
         if Backend.isDbms(DBMS.MYSQL):
             self.getCurrentUser()
-            if Backend.isFork(FORK.DRIZZLE):
+            if Backend.isDbms(DBMS.MYSQL) and Backend.isFork(FORK.DRIZZLE):
                 kb.data.isDba = "root" in (kb.data.currentUser or "")
             elif kb.data.currentUser:
                 query = queries[Backend.getIdentifiedDbms()].is_dba.query % kb.data.currentUser.split("@")[0]
@@ -106,7 +106,7 @@ class Users(object):
         condition |= (Backend.isDbms(DBMS.MYSQL) and not kb.data.has_information_schema)
 
         if any(isTechniqueAvailable(_) for _ in (PAYLOAD.TECHNIQUE.UNION, PAYLOAD.TECHNIQUE.ERROR, PAYLOAD.TECHNIQUE.QUERY)) or conf.direct:
-            if Backend.isFork(FORK.DRIZZLE):
+            if Backend.isDbms(DBMS.MYSQL) and Backend.isFork(FORK.DRIZZLE):
                 query = rootQuery.inband.query3
             elif condition:
                 query = rootQuery.inband.query2
@@ -126,7 +126,7 @@ class Users(object):
             infoMsg = "fetching number of database users"
             logger.info(infoMsg)
 
-            if Backend.isFork(FORK.DRIZZLE):
+            if Backend.isDbms(DBMS.MYSQL) and Backend.isFork(FORK.DRIZZLE):
                 query = rootQuery.blind.count3
             elif condition:
                 query = rootQuery.blind.count2
@@ -147,7 +147,7 @@ class Users(object):
             for index in indexRange:
                 if Backend.getIdentifiedDbms() in (DBMS.SYBASE, DBMS.MAXDB):
                     query = rootQuery.blind.query % (kb.data.cachedUsers[-1] if kb.data.cachedUsers else " ")
-                elif Backend.isFork(FORK.DRIZZLE):
+                elif Backend.isDbms(DBMS.MYSQL) and Backend.isFork(FORK.DRIZZLE):
                     query = rootQuery.blind.query3 % index
                 elif condition:
                     query = rootQuery.blind.query2 % index
@@ -276,7 +276,7 @@ class Users(object):
                     if user in retrievedUsers:
                         continue
 
-                    if Backend.isDbms(DBMS.INFORMIX):
+                    if Backend.getIdentifiedDbms() in (DBMS.INFORMIX, DBMS.VIRTUOSO):
                         count = 1
                     else:
                         infoMsg = "fetching number of password hashes "
@@ -301,7 +301,7 @@ class Users(object):
                         if not isNumPosStrValue(count):
                             warnMsg = "unable to retrieve the number of password "
                             warnMsg += "hashes for user '%s'" % user
-                            logger.warn(warnMsg)
+                            logger.warning(warnMsg)
                             continue
 
                     infoMsg = "fetching password hashes for user '%s'" % user
@@ -322,7 +322,7 @@ class Users(object):
                             if fallback:
                                 query = query.replace("master.dbo.fn_varbintohexstr", "sys.fn_sqlvarbasetostr")
 
-                        elif Backend.isDbms(DBMS.INFORMIX):
+                        elif Backend.getIdentifiedDbms() in (DBMS.INFORMIX, DBMS.VIRTUOSO):
                             query = rootQuery.blind.query % (user,)
 
                         elif Backend.isDbms(DBMS.HSQLDB):
@@ -345,7 +345,7 @@ class Users(object):
                     else:
                         warnMsg = "unable to retrieve the password "
                         warnMsg += "hashes for user '%s'" % user
-                        logger.warn(warnMsg)
+                        logger.warning(warnMsg)
 
                     retrievedUsers.add(user)
 
@@ -547,7 +547,7 @@ class Users(object):
 
                         warnMsg = "unable to retrieve the number of "
                         warnMsg += "privileges for user '%s'" % outuser
-                        logger.warn(warnMsg)
+                        logger.warning(warnMsg)
                         continue
 
                 infoMsg = "fetching privileges for user '%s'" % outuser
@@ -650,7 +650,7 @@ class Users(object):
                 else:
                     warnMsg = "unable to retrieve the privileges "
                     warnMsg += "for user '%s'" % outuser
-                    logger.warn(warnMsg)
+                    logger.warning(warnMsg)
 
                 retrievedUsers.add(user)
 
@@ -668,6 +668,6 @@ class Users(object):
     def getRoles(self, query2=False):
         warnMsg = "on %s the concept of roles does not " % Backend.getIdentifiedDbms()
         warnMsg += "exist. sqlmap will enumerate privileges instead"
-        logger.warn(warnMsg)
+        logger.warning(warnMsg)
 
         return self.getPrivileges(query2)
